@@ -1,6 +1,6 @@
 #========================================================================
 #
-# Badger::Codec::Storable
+# Badger::Codec::Chain
 #
 # DESCRIPTION
 #   Codec for encoding/decoding data via a chain of other codecs.
@@ -172,11 +172,11 @@ chain.
 
 =head1 AUTHOR
 
-Andy Wardley E<lt>abw@wardley.orgE<gt>
+Andy Wardley L<http://wardley.org/>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2008 Andy Wardley. All rights reserved.
+Copyright (C) 2005-2009 Andy Wardley. All rights reserved.
 
 =head1 SEE ALSO
 
